.. _faq:

===========================
Frequently Asked Questions
===========================

.. contents:: :local:

How can I add a question here?
------------------------------

See `Contributing <contributing.rst>`_ for how to report bugs and ask questions. (hint: open a github issue)


How should I cite LightRayRider?
--------------------------------

Please cite Buchner & Bauer (2017), http://adsabs.harvard.edu/abs/2017MNRAS.465.4348B

They describe the underlying techniques.

